==> maDB_1.4.0.tar.gz: maDB/man/updateDBAnnotation.Rd <==
\name{dbUpdateAnnotation}
\alias{dbUpdateAnnotation}
\title{Create and update an annotation table in a PostgreSQL database.}
\description{
  \code{dbUpdateAnnotation} this handy function help you to easily create an annotation database in a database and to keep the annotation in the database up to date.
}
\usage{
dbUpdateAnnotation(Con,data,chip,date,do.backup=TRUE,v=TRUE)
}
\arguments{
  \item{Con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{data}{The annotation table. The column names of the table have to be \code{"id","gen_bank","description","uni_gene","locuslink"}. The order of the columns is not important.}
  \item{chip}{An identifier for the chip or array (oligo set) respectiveley.}
  \item{date}{The date when the annotation was created (better said the annotation was up to date).}
  \item{do.backup}{If a backup of the annotation table should be done. This is usefull when the annotation of an already existing table is going to be updated. By default the annotations of the chip that will be updated will be saved as a tab delimited txt file. The file name of the txt file consists of the chip and the date and the file will be saved in the current workspace.}
  \item{v}{If TRUE additional information will be printed to the console.}
}
\details{
When creating or updating the database not all columns have to be submitted in the \code{data} argument, when submitting a table with only some of the columns the other columns in the database will remain empty.
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{dbGetAnnotation}}
    \code{\link{insertIntoTable}}
    \code{\link{dbConnect}}
    \code{\link{updateDBTable}}
}

\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/updateDBAnnotation.Rd <==
\name{dbUpdateAnnotation}
\alias{dbUpdateAnnotation}
\title{Create and update an annotation table in a PostgreSQL database.}
\description{
  \code{dbUpdateAnnotation} this handy function help you to easily create an annotation database in a database and to keep the annotation in the database up to date.
}
\usage{
dbUpdateAnnotation(Con,data,chip,date,do.backup=TRUE,v=TRUE)
}
\arguments{
  \item{Con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{data}{The annotation table. The column names of the table have to be \code{"id","gen_bank","description","uni_gene","locuslink"}. The order of the columns is not important.}
  \item{chip}{An identifier for the chip or array (oligo set) respectiveley.}
  \item{date}{The date when the annotation was created (better said the annotation was up to date).}
  \item{do.backup}{If a backup of the annotation table should be done. This is usefull when the annotation of an already existing table is going to be updated. By default the annotations of the chip that will be updated will be saved as a tab delimited txt file. The file name of the txt file consists of the chip and the date and the file will be saved in the current workspace.}
  \item{v}{If TRUE additional information will be printed to the console.}
}
\details{
When creating or updating the database not all columns have to be submitted in the \code{data} argument, when submitting a table with only some of the columns the other columns in the database will remain empty.
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{dbGetAnnotation}}
%    \code{\link{insertIntoTable}}
%    \code{\link{dbConnect}}
%    \code{\link{updateDBTable}}
}

\keyword{data}
